.. _datasets:

Datasets
========

Generate toy data
-----------------
.. currentmodule:: skchange.datasets

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    generate_piecewise_data
    generate_piecewise_normal_data
    generate_piecewise_regression_data
    generate_continuous_piecewise_linear_data

Load real datasets
------------------

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    load_hvac_system_data

Deprecated
----------
.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    generate_anomalous_data
    generate_changing_data
    generate_alternating_data
